<!---
	COMPONENT: ContactBeanerFilter
	AUTHOR: Ben Edwards (?)
	DATE: unknown
	PURPOSE: ContactBeanerFilter for Mach-II Contact Manager sample application.  This filter
				makes sure an instance of the Contact object is available in the event.
	CHANGE HISTORY:
		* unknown: component created (Ben Edwards?)
		* 7/17/2005: component updated based on use of new EventInvoker (removes reliance on request scope) 
						and incorporated into Mach-II Contact Manager sample app
						(Matt Woodward - mpwoodward@gmail.com)
--->

<cfcomponent display="ContactBeanerFilter" extends="MachII.framework.EventFilter" output="false" 
		hint="Filter to ensure that there is an instance of the Contact object available in the event">
	
	<cffunction name="filterEvent" access="public" output="false" returntype="boolean">
		<cfargument name="event" type="MachII.framework.Event" required="true" />
		<cfargument name="eventContext" type="MachII.framework.EventContext" required="true" />
		<cfargument name="paramArgs" type="struct" required="false" default="#StructNew()#" />
		
		<cfscript>
			// set default for contact object
			var contact = "";
			
			if (arguments.event.isArgDefined("contact")) {
				// don't do anything -- contact already exists in the event
			} else {
				// contact doesn't exist, so create object based on parameters in the event, 
				// setting defaults to "" if the argument doesn't exist
				contact = CreateObject("component", "ContactManager.model.Contact");
				
				contact.setId(arguments.event.getArg("id", ""));
				contact.setFirstName(arguments.event.getArg("firstName", ""));
				contact.setLastName(arguments.event.getArg("lastName", ""));
				contact.setStreet(arguments.event.getArg("street", ""));
				contact.setCity(arguments.event.getArg("city", ""));
				contact.setState(arguments.event.getArg("state", ""));
				contact.setZip(arguments.event.getArg("zip", ""));
				
				// put contact in event
				arguments.event.setArg("contact", contact);
			}
		</cfscript>
		
		<cfreturn true />
	</cffunction>
	
</cfcomponent>